@@ -5,19 +5,21 @@ use Carp;
 use base qw( Search::OpenSearch::Response );
 use JSON;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub stringify {
     my $self = shift;
 
     my $resp = $self->as_hash;
-
+    
     # in devel mode use pretty()
     return $self->debug
         ? JSON->new->utf8->pretty(1)->encode($resp)
         : encode_json($resp);
 }
 
+sub content_type { return 'application/json' }
+
 1;
 
 __END__
@@ -73,6 +75,10 @@ Returns the Response in JSON format.
 
 Response objects are overloaded to call stringify().
 
+=head2 content_type
+
+Returns appropriate MIME type for the format returned by stringify().
+
 =head1 AUTHOR
 
 Peter Karman, C<< <karman at cpan.org> >>
